@@ -312,7 +312,7 @@ class System(object):
                             sorted_versions = sorted_versions[:len(sorted_versions) - 1]
                             stripdone = True
 
-                if not stripdone:
+                if not stripdone or len(sorted_versions) < 1:
                     break
 
             if len(sorted_versions) < 1:
@@ -321,13 +321,16 @@ class System(object):
             result = (plugin, sorted_versions[0][0])
             return result
 
-    def ittrPluginsByComponent(self, component):
+    def ittrPluginsByComponent(self, component, requierments=None):
         """
         iterates over the all possible providers of a component returning the plugin name and the highest version avalible.
         """
-        for name, versions in self.components[component].items():
-            version = sorted(self.components[component][name], key=operator.itemgetter(1), reverse=True)[0][0]
-            yield (name, version)
+        for plugin_name, versions in self.components[component].items():
+            version_req = ""
+            if not requierments is None and plugin_name in requierments:
+                version_req = requierments[plugin_name]
+            plugin, version = self.resolve_highest_match(component, plugin_name, version_req)
+            yield (plugin, version)
 
     def load(self, component, requierments=None, bypass=False):
         """
